@@ -1,7 +1,7 @@
 #! /bin/sh
 
 top=`pwd`
-gcc_version=4.7.1
+gcc_version=4.7.2
 contact="Andris Pavenis <andris.pavenis@iki.fi>";
 
 # Configuration params
@@ -56,47 +56,35 @@ if ! [ -f s-sources ] ; then
     exit 1
 fi
 
-dir_name=`(cd gnu && ls -d gcc* | sed 1q; )`
+orig_dir_name=`(cd gnu && ls -d gcc* | sed 1q; )`
 
-short_version=`cat gnu/$dir_name/gcc/BASE-VER`
-short_version_2=`echo $short_version | sed -e 's:\.::2g'`
-short_version_3=`echo $short_version | sed -e 's:\.::g'`
-datestamp=`cat gnu/$dir_name/gcc/DATESTAMP`
-devphase=`cat gnu/$dir_name/gcc/DEV-PHASE`
-version="$short_version $datestamp ($devphase)"
+base_ver=$(cat gnu/$orig_dir_name/gcc/BASE-VER)
+datestamp=$(cat gnu/$orig_dir_name/gcc/DATESTAMP)
+devphase=$(cat gnu/$orig_dir_name/gcc/DEV-PHASE)
+version=$base_ver
+version_desc=$version
 
-if ! [ -z "$devphase" ] ; then
-    version_status="-$devphase"
+#  X.Y.Z ==> X.YZ
+short_ver=$(echo $version | sed -e 's:\.::2g')
+
+#  X.Y.Z ==> XYZ
+short_ver_2=$(echo $version | sed -e 's:\.::g')
+
+if ! test -z "$devphase"; then
+    version=${base_ver}-${datestamp}
+    version_desc="$base_ver $datestamp ($devphase)"
+    short_ver=${short_ver}-$datestamp
+    short_ver_2=${short_ver_2}-$datestamp
 fi
 
-arcprefix=gcc$short_version_3
-srcname=gcc-$short_version_2 
+dir_name=gcc-$short_ver
 
-if ! [ -z "$version_status" ] ; then
-    version_status="-${datestamp}-${devphase}"
-fi 
-
-dir_name0=$dir_name
-case $dir_name in
-    gcc-[3-9].[0-9]-*)
-        ;;
-    gcc-[3-9].[0-9])
-        ;;
-    gcc-[3-9].[0-9].[0-9]*)
-        dir_name=`echo $dir_name | sed -e 's,\.,,2g'`
-        ;;
-    gcc-[3-9].[0-9]-[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]|\
-    gcc-[3-9].[0-9].[0-9]-[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9])
-        ;;
-    gcc)
-        dir_name=$srcname$version_status
-        ;;
-esac
-
-if ! test "$dir_name" = "$dir_name0" ; then
-    mv -f gnu/$dir_name0 gnu/$dir_name || exit 1
+if ! test "$dir_name" = "$orig_dir_name" ; then
+    mv -f gnu/$orig_dir_name gnu/$dir_name || exit 1
 fi
 
+arcprefix=gcc$short_ver_2
+
 if [ -d $top/gnu/$dir_name ] ; then
     gcc_dir=$top/gnu/$dir_name
 else
@@ -200,12 +188,12 @@ for x in $patch_instr_list_1 $patch_instr_list_2; do
     x=$(echo $x | sed -e 's:diffs2*/source/::')
 
     case $x in 
-       *.diff | *.diff.in)
+       *.diff | *.diff[0-9] | *.diff[0-9][0-9])
            cd $top
            diff=`pwd`/$x;
-           fname=`echo $x | sed -e 's/\.diff//g'`
+           fname=`echo $x | sed -e 's/\.diff[0-9]*//g'`
 
-           echo "Applying patch to gcc/$fname ..."
+           echo "Applying patch $x to gcc/$fname ..."
            if [ -f $gcc_dir/$fname ] ; then
               cp -f $gcc_dir/$fname $gcc_dir/${fname}~1 
               if ! patch --verbose --suffix=$backup_name $gcc_dir/$fname <$patch_src ; then
@@ -228,9 +216,9 @@ for x in $patch_instr_list_1 $patch_instr_list_2; do
            ;;
        readme.DJGPP)
            cat diffs/source/$x |\
-           sed -e "s:@GCCVER@:$short_version:g" \
-	       -e "s:@GCCVER2@:$short_version_2:g" \
-	       -e "s:@GCCVER3@:$short_version_3:g" \
+           sed -e "s:@GCCVER@:$version_desc:g" \
+	       -e "s:@GCCVER2@:$short_ver:g" \
+	       -e "s:@GCCVER3@:$short_ver_2:g" \
 	       -e "s:@CONTACT@:$contact:g" \
 	    	    >$gcc_dir/$x
 	   ;;
@@ -259,7 +247,7 @@ if $create_gccnnns_zip; then
             mkdir -p `dirname gnu/$dir/$x`
 	    echo "Writting $dir/$x"
 	    cat diffs2/$dir/$x |\
-	    sed -e "s:@SRCDIR@:$dir_name:g" -e "s:@GCCVER@:$short_version:g" >gnu/$dir/$x
+	    sed -e "s:@SRCDIR@:$dir_name:g" -e "s:@GCCVER@:$version:g" >gnu/$dir/$x
         done
     done
 fi
@@ -351,8 +339,8 @@ cd $top
 
 if $create_gccnnns_zip; then
     mkdir manifest
-    echo ${arcprefix}s${version_status}.zip - GCC $version source archive for DJGPP >$top/manifest/${arcprefix}s${version_status}.ver
-    touch $top/manifest/${arcprefix}s${version_status}.mft
+    echo ${arcprefix}s.zip - GCC $version source archive for DJGPP >$top/manifest/${arcprefix}s.ver
+    touch $top/manifest/${arcprefix}s.mft
 
     (
         find gnu -type f \
@@ -361,7 +349,7 @@ if $create_gccnnns_zip; then
             -and -not -name '*.orig' \
             -and -not -name '.brik' ;
         find manifest -type f;
-    ) | grep -v 'autom4te\.cache' | sort >$top/manifest/${arcprefix}s${version_status}.mft
+    ) | grep -v 'autom4te\.cache' | sort >$top/manifest/${arcprefix}s.mft
 
-    cat $top/manifest/${arcprefix}s${version_status}.mft | zip -9q@ $top/${arcprefix}s${version_status}.zip
+    cat $top/manifest/${arcprefix}s.mft | zip -9q@ $top/${arcprefix}s.zip
 fi
